@@ -32,5 +32,8 @@ SHIPPING = getattr(settings, 'PAYPAL_USE_SHIPPING', False)
 DEFAULT_CURRENCY = getattr(settings, 'DEFAULT_CURRENCY', 'USD')
 set_default_currency(code=DEFAULT_CURRENCY)
 
+DECIMAL_PLACES = getattr(settings, 'PAYPAL_DECIMAL_PLACES', 2)
+MAX_DIGITS = getattr(settings, 'PAYPAL_MAX_DIGITS', 10)
+
 # Should tests hit Paypaladaptive or not? Defaults to using mock responses
 TEST_WITH_MOCK = getattr(settings, 'PAYPAL_TEST_WITH_MOCK', True)
